Jmbo
====
**The Jmbo base product introduces a content type and various tools required to build Jmbo products.**

.. figure:: https://travis-ci.org/praekelt/jmbo.svg?branch=develop
   :align: center
   :alt: Travis

Documentation at http://jmbo.readthedocs.org.

